check_identity_availability

Function check_identity_availability 

pub async fn check_identity_availability(
    __arg0: State<App>,
    tn_id: TnId,
    __arg2: IdTag,
    __arg3: Query<CheckAvailabilityQuery>,
    __arg4: OptionalRequestId,
) -> ClResult<(StatusCode, Json<ApiResponse<AvailabilityResponse>>)>
GET /api/idp/check-availability - Check if an identity id_tag is available

This endpoint checks if an identity is available for registration within the authenticated tenant’s domain. The identity must belong to the same domain as the authenticated tenant.